/*
 *  Avis Elvin client library for Java.
 *  
 *  Copyright (C) 2008 Matthew Phillips <avis@mattp.name>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 3 of the GNU Lesser General
 *  Public License as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *  General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package org.avis.client.examples;

import java.io.InputStreamReader;

import org.avis.client.Elvin;
import org.avis.client.Notification;

/*
 * This is the broadcaster part of the "wall" example. In this
 * example, one or more "wall" broadcasters send typed characters from
 * the console to zero or more wall receivers.
 * 
 * See the documentation in "doc/examples.txt" for instructions on how to
 * use the Avis examples.
 */
public class WallBroadcaster
{
  public static void main (String [] args)
    throws Exception
  {
    Elvin elvin = 
      new Elvin (System.getProperty ("elvin", "elvin://localhost"));
    
    elvin.closeOnExit ();
    
    System.out.println ("Type some lines of text to be broadcast over Elvin.");
    System.out.println ("Hit Ctrl+C to exit.");
    
    // read from stdin one character at a time and send over Elvin
    InputStreamReader in = new InputStreamReader (System.in);
    
    int ch;
    
    while ((ch = in.read ()) != -1)
    {
      Notification notification = new Notification ();
      
      notification.set ("From", "wall");
      notification.set ("Typed-Character", ch);
      
      elvin.send (notification);
    }
    
    elvin.close ();
  }
}
