/*
 *  Avis Elvin client library for Java.
 *  
 *  Copyright (C) 2008 Matthew Phillips <avis@mattp.name>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 3 of the GNU Lesser General
 *  Public License as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *  General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package org.avis.tools;

import java.util.Queue;

import org.avis.util.IllegalCommandLineOption;

/**
 * Options for the ec command.
 * 
 * @author Matthew Phillips
 */
public class EcOptions extends ToolOptions
{
  public static final String USAGE =
    COMMON_USAGE_SUMMARY + " subscription\n\n" + COMMON_USAGE_DETAIL;

  /**
   * The subscription expression.
   */
  public String subscription;

  public EcOptions (String... args)
  {
    super (args);
  }
  
  @Override
  protected void handleArg (Queue<String> args)
    throws IllegalCommandLineOption
  {
    String arg = args.peek ();
    
    if (!arg.startsWith ("-"))
    {
      if (subscription == null)
        subscription = args.remove ();
      else
        throw new IllegalCommandLineOption ("Can only have one subscription");
    } else
    {
      super.handleArg (args);
    }
  }
  
  @Override
  protected void checkOptions ()
  {
    super.checkOptions ();

    if (subscription == null)
      throw new IllegalCommandLineOption ("No subscription specified");
  }
}
